ig.module
(
	'game.entities.player'
)
.requires
(
	'impact.entity',
	'game.bullet',
	'game.blood'
)
.defines(function ()
{
    EntityPlayer = ig.Entity.extend(
	{
		hit_sound: new ig.Sound('media/player_hit1.*'),
		rain_sound: new ig.Sound('media/rain1.*'),
		rain_music: new ig.Music(),
		shoot_sound: new ig.Sound('media/shot2.*'),
	    animSheet: new ig.AnimationSheet('media/player2.png', 16, 16),
	    size: { x: 9, y: 15 },
	    offset: { x: 4, y: 1 },
	    collides: ig.Entity.COLLIDES.ACTIVE,
	    type: ig.Entity.TYPE.A,
	    checkAgainst: ig.Entity.TYPE.NONE,
	    zIndex: 50,
	    maxVel: { x: 300, y: 300 },
	    friction: { x: 20, y: 50 },
	    gravityFactor: 1,

	    speed: 70,
	    n: 0,

	    dir: -1,

	    in_rain: false,
	    rain_timer: null,

	    shoot_timer: null,

	    init: function (x, y, settings)
	    {
	        this.parent(x, y, settings);

	        this.addAnim('idle', 1, [0]);
	        this.addAnim('walk', 0.1, [1, 2, 3, 4]);

	        this.rain_music.add(this.rain_sound);
	        this.rain_music.loop = true;
	        this.rain_music.volume = 0.2;

	        this.rain_timer = new ig.Timer();
	        this.shoot_timer = new ig.Timer();
	    },

	    update: function()
	    {
	    	if (!this.in_rain && this.rain_timer.delta() >= 0)
	   			this.rain_music.pause();
	    	else
	    		this.rain_music.play();

		    this.vel.x = this.speed * ((ig.input.state('right') ? 1 : 0) - (ig.input.state('left') ? 1 : 0));

		    if (ig.input.pressed('jump') && this.standing)
		    {
		    	this.vel.y = -200;
		    }
		    else if (ig.input.released('jump') && !this.standing)
		    {
		    	if (this.vel.y < 0)
		    		this.vel.y = 0;
		    }

		    if (ig.input.pressed('shoot') && this.shoot_timer.delta() >= 0)
		    {
		    	this.shoot_timer.set(0.25);
		    	this.shoot_sound.play();
		    	ig.game.spawnEntity(Bullet, this.pos.x + (this.dir > 0 ? 16 : 0), this.pos.y + 5, { dir: this.dir });
		    }

		    if (this.pos.x < 0)
		    	this.pos.x = 0;
		    else if (this.pos.x + this.size.x >= ig.system.width + this.size.x)
		    	this.pos.x = ig.system.width - this.size.x;

		    if (this.pos.y < 0)
		    	this.pos.y = 0;
		    else if (this.pos.y + this.size.y >= ig.system.height + this.size.y)
		    	this.pos.y = ig.system.height - this.size.y;

			if (this.vel.x != 0)
				this.currentAnim = this.anims.walk;
			else
				this.currentAnim = this.anims.idle;

			if (this.vel.x > 0)				
				this.dir = 1;
			else if (this.vel.x < 0)
				this.dir = -1;
	
			if (this.dir > 0)
				this.currentAnim.flip.x = true;
			else
				this.currentAnim.flip.x = false;

	    	this.parent();

	    	this.in_rain = false;
	    },

	    handleMovementTrace: function(res)
		{
			this.parent(res);
		},	

	    draw: function ()
	    {
	        this.parent();
	    },

	    receiveDamage: function(amount, from)
	    {
	    	this.hit_sound.play();

			for (var i = 0; i < 200; ++i)
				ig.game.spawnEntity(Blood, this.pos.x + Math.random() * this.size.x, this.pos.y + Math.random() * this.size.y, { dir: -this.dir });

		 	ig.game.start_gameover();

	    	this.kill();
	    },

	    rain: function()
	    {
	    	this.in_rain = true;
	    	this.rain_timer.set(1);
	    }
	});
});
