ig.module
(
	'game.entities.zombie'
)
.requires
(
	'impact.entity',
	'impact.entity-pool',
	'game.dirt',
	'game.blood'
)
.defines(function()
{
	EntityZombie = ig.Entity.extend(
	{
		anim_sheets: [ new ig.AnimationSheet('media/zombie12.png', 16, 16), new ig.AnimationSheet('media/zombie22.png', 16, 16), new ig.AnimationSheet('media/skeleton12.png', 16, 16) ],

		hit_sound: [new ig.Sound('media/zombie_hit1.*'), new ig.Sound('media/zombie_hit2.*') ],
		hit2_sound: new ig.Sound('media/zombie_hit3.*'),
		size: { x: 8, y: 15 },
		offset: { x: 4, y: 1 },

		collides: ig.Entity.COLLIDES.NEVER,
		type: ig.Entity.TYPE.B,
		checkAgainst: ig.Entity.TYPE.A,

		gravityFactor: 1,

		maxVel: { x: 10, y: 100 },
		friction: { x: 0, y: 0 },

		zIndex: 17,

		spawned_finish: false,

		start_speed: 4,

		t: 0,

		zombie_type: 0,

		BLOODS: [ Blood, Blood, Blood2 ],
		
		init: function(x, y, settings)
		{
			this.parent(x, y, settings);

			this.reset(x, y, settings);
		},

		reset: function(x, y, settings)
		{
			this.parent(x, y, settings);

			this.zombie_type = Math.floor(Math.random() * this.anim_sheets.length);
			this.animSheet = this.anim_sheets[this.zombie_type];

			this.addAnim('rise', 0.2, [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13], true);
			this.addAnim('walk', 0.2, [14, 15, 16, 15]);

			this.vel.x = 0;
			this.vel.y = 0;
			this.accel.x = 0;
			this.accel.y = 0;
			this.maxVel.x = 5 + 10 * Math.random();

			this.timer = new ig.Timer(3);

			this.currentAnim = this.anims.rise.rewind();

			this.spawned_finish = false;
			this.collides = ig.Entity.COLLIDES.NEVER;
		},

		update: function()
		{
			this.parent();

			if (this.vel.x > 0)				
				this.currentAnim.flip.x = true;
			else if (this.vel.x < 0)
				this.currentAnim.flip.x = false;

			if (!this.spawned_finish)
			{
				if (this.timer.delta() > 0)
				{
//					this.collides = ig.Entity.COLLIDES.PASSIVE;
					this.spawned_finish = true;
					this.accel.x = (this.start_speed + Math.random() * this.start_speed) * (Math.random() >= 0.5 ? 1 : -1);
					this.currentAnim = this.anims.walk;
					this.timer.pause();
				}

				if (this.timer.delta() < -2)				
				{
					ig.game.spawnEntity(Dirt, this.pos.x + Math.random() * this.size.x, this.pos.y + this.size.y - 2);
				}
			}
		},

		handleMovementTrace: function(res)
		{
			this.t = ig.game.collisionMap.trace(this.pos.x, this.pos.y, (this.vel.x > 0 ? +10 : -10), 1, this.size.x, this.size.y);
			if(!this.t.collision.y || this.t.collision.x)
			{
				this.vel.x *= -1;
			   	this.accel.x *= -1;
			}

			this.parent(res);
		},

		check: function(other)
		{
			if (!this.spawned_finish)
				return false;

			if (other instanceof EntityPlayer)
				other.receiveDamage(1, this);
		},

		receiveDamage: function(amount, from)
		{
			if (!this.spawned_finish)
				return false;

			for (var i = 0; i < 50; ++i)
				ig.game.spawnEntity(this.BLOODS[this.zombie_type], this.pos.x + Math.random() * this.size.x, this.pos.y + Math.random() * this.size.y, { dir: from.dir });

			this.hit_sound[Math.floor(Math.random() * this.hit_sound.length)].play();

			if (Math.random() > 0.6)
				this.hit2_sound.play();
			
			this.kill();

			ig.global.ld29_player_score += 1;

			return true;
		},
	});

	ig.EntityPool.enableFor(EntityZombie);
});